from django.conf.urls.defaults import *

from csnews.feeds import LatestNews
#feed_dict = {'rss': LatestNews}

urlpatterns = patterns('',
    (r'^$','csnews.views.index'),
    (r'^feed/$', LatestNews()),
    (r'^hemeroteka/', 'csnews.views.hemeroteka'),            
    (r'^(?P<article_slug>[\-\d\w]+)/$','csnews.views.article_index'),
)




from csnews.utils.load_images import loadUrlImage
from csnews.models import Article
from lxml import etree
from django.template.defaultfilters import slugify
from django.conf import settings

from datetime import datetime

#BASE_PATH = 'http://www.ahotsak.com/news'
#END_PATH = 'export.xml'

   
def get_news():
    path = '%s/%s' % (settings.BASE_PATH, settings.END_PATH)
    coords = etree.parse(path).getroot()

    all = []
    for coord in coords:
        this = {}
        for child in coord.getchildren():
            this[child.tag] = child.text
        all.append(this)
    return all
    

def get_datetime_from_string(s):
    """ """
    f = '%Y/%m/%d %H:%M:%S'
    return datetime.strptime(s,f)

def load_news():
    """ """
    for new in get_news():
        try:
            image_url = new['image_url']
            image_format = image_url[-3:]
            photo = loadUrlImage(image_url, 'Albistea: %s' % new['title'], 'albistea',image_format)
        except:
            photo = None
        article = Article()
        article.title=new['title']
        article.summary = new['summary']
        article.body = new['body']
        article.slug = slugify(article.title)[:50]
        sdate = new['date']
        sdate = ' '.join(sdate.split(' ')[:-1])        
        article.published = get_datetime_from_string(sdate)
        if photo:
            article.image = photo
        article.tags = new['author'].lower()
        article.save()
        print article.title
    return 1 



from setuptools import setup, find_packages
import sys, os

version = '0.7'

setup(name='csnews',
      version=version,
      description="Simple news module",
      long_description=open("README.md").read(),
      classifiers=[], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='',
      author='Urtzi Odriozola',
      author_email='uodriozola@codesyntax.com',
      url='http://www.codesyntax.com',
      license='GPL',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          # -*- Extra requirements: -*-
          'django-photologue',
      ],
      entry_points="""
# -*- Entry points: -*-
""",
      )
